@@ -94,11 +94,11 @@ class DirectionalVariogram(Variogram):
         bin_func : str
             .. versionchanged:: 0.3.8
                 added 'fd', 'sturges', 'scott', 'sqrt', 'doane'
-            
+
             String identifying the binning function used to find lag class
             edges. All methods calculate bin edges on the interval [0, maxlag[.
             Possible values are:
-            
+
                 * `'even'` (default) finds `n_lags` same width bins
                 * `'uniform'` forms `n_lags` bins of same data count
                 * `'fd'` applies Freedman-Diaconis estimator to find `n_lags`
@@ -213,7 +213,7 @@ class DirectionalVariogram(Variogram):
             used for histogram calculation.
         percentile : int
             .. versionadded:: 0.3.7
-            
+
             If the `estimator <skgstat.Variogram.estimator>` is set to
             `'entropy'` this argument sets the percentile to be used.
 
@@ -232,11 +232,11 @@ class DirectionalVariogram(Variogram):
             coordinates = np.asarray(coordinates)
             coordinates = MetricSpace(coordinates.copy(), dist_func)
             # FIXME: Currently _direction_mask / _angles / _euclidean_dist don't get correctly calculated for sparse dspaces
-            #coordinates = MetricSpace(coordinates.copy(), dist_func, maxlag if maxlag and not isinstance(maxlag, str) and maxlag >= 1 else None)
+            # coordinates = MetricSpace(coordinates.copy(), dist_func, maxlag if maxlag and not isinstance(maxlag, str) and maxlag >= 1 else None)
         else:
             assert self.dist_func == coordinates.dist_metric, "Distance metric of variogram differs from distance metric of coordinates"
             assert coordinates.max_dist is None
-            
+
         # Set coordinates
         self._X = coordinates
 
@@ -246,11 +246,16 @@ class DirectionalVariogram(Variogram):
         # set verbosity
         self.verbose = verbose
 
+        # declare a flag to mark if this is a covariogram
+        # this is set to None, as set_values will figure out
+        self._is_cross = None
+        self._co_variable = None
+
         # set values
         self._values = None
         # calc_diff = False here, because it will be calculated by fit() later
         self.set_values(values=values, calc_diff=False)
-        
+
         # distance matrix
         self._dist = None
 
@@ -319,6 +324,12 @@ class DirectionalVariogram(Variogram):
         # Note that fit() calls preprocessing
         self.fit(force=True)
 
+        # finally check if any of the uncertainty propagation kwargs are set
+        self._experimental_conf_interval = None
+        self._model_conf_interval = None
+        if 'obs_sigma' in self._kwargs:
+            self._propagate_obs_sigma()
+
     def preprocessing(self, force=False):
         self._calc_direction_mask_data(force)
         self._calc_diff(force=force)
@@ -356,7 +367,7 @@ class DirectionalVariogram(Variogram):
 
         # FIXME: This should be optimized for the sparse case (range << bbox(coordinates)),
         # i.e. use the MetricSpace in self._X
-        
+
         # check if already calculated
         if self._angles is not None and not force:
             return
@@ -371,9 +382,9 @@ class DirectionalVariogram(Variogram):
 
         # for angles, we need Euklidean distance,
         # no matter which distance function is used
-        #if self._dist_func_name == "euclidean":
+        # if self._dist_func_name == "euclidean":
         #    self._euclidean_dist = scipy.spatial.distance.squareform(self.distance_matrix)
-        #else:
+        # else:
         self._euclidean_dist = pdist(_x, "euclidean")
 
         # Calculate the angles
@@ -391,7 +402,6 @@ class DirectionalVariogram(Variogram):
         # amount of the x coordinate
         self._angles = np.where(ydiff >= 0, pos_angles, -pos_angles)
 
-
     @property
     def azimuth(self):
         """Direction azimuth
